@@ -198,6 +198,8 @@
 #include "token_info-5.22.0.h"
 #elif PERL_VERSION == 22 && PERL_SUBVERSION == 3
 #include "token_info-5.22.0.h"
+#elif PERL_VERSION == 22 && PERL_SUBVERSION == 4
+#include "token_info-5.22.0.h"
 #elif PERL_VERSION == 22
 #include "token_info-5.22.0.h"
 #elif PERL_VERSION == 23 && PERL_SUBVERSION == 0
@@ -224,6 +226,10 @@
 #include "token_info-5.24.0.h"
 #elif PERL_VERSION == 24 && PERL_SUBVERSION == 1
 #include "token_info-5.24.0.h"
+#elif PERL_VERSION == 24 && PERL_SUBVERSION == 2
+#include "token_info-5.24.0.h"
+#elif PERL_VERSION == 24 && PERL_SUBVERSION == 3
+#include "token_info-5.24.0.h"
 #elif PERL_VERSION == 24
 #include "token_info-5.24.0.h"
 #elif PERL_VERSION == 25 && PERL_SUBVERSION == 0
@@ -254,7 +260,25 @@
 #include "token_info-5.25.8.h"
 #elif PERL_VERSION == 26 && PERL_SUBVERSION == 0
 #include "token_info-5.26.0.h"
-#elif PERL_VERSION > 26 || (PERL_VERSION == 26 && PERL_SUBVERSION > 0)
+#elif PERL_VERSION == 26 && PERL_SUBVERSION == 1
+#include "token_info-5.26.0.h"
+#elif PERL_VERSION == 26
+#include "token_info-5.26.0.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 0
+#include "token_info-5.27.0.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 1
+#include "token_info-5.27.0.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 2
+#include "token_info-5.27.0.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 3
+#include "token_info-5.27.0.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 4
+#include "token_info-5.27.0.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 5
+#include "token_info-5.27.0.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 6
+#include "token_info-5.27.0.h"
+#elif PERL_VERSION > 27 || (PERL_VERSION == 27 && PERL_SUBVERSION > 6)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
